ExpressionVisitor<T> class abstract

Constructors

ExpressionVisitor()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visitList(ExpressionList expression) → T
visitLiteral(LiteralExpression expression) → T
visitReference(ReferenceExpression expression) → T
visitSelect(MultipleExpression expression) → T

Operators

operator ==(Object other) → bool
The equality operator.
inherited